@@ -114,10 +114,16 @@ def eth_signTransaction(tx):
     return personal_sign_transaction([tx, ''])
 
 
+def eth_sign(address, message):
+    logg.debug('got message {} to sign'.format(p[0]))
+    return signer.signEthereumMessage(address, message)
+
+
 methods = {
         'personal_newAccount': personal_new_account,
         'personal_signTransaction': personal_sign_transaction,
         'eth_signTransaction': eth_signTransaction,
+        'eth_sign': eth_sign,
     }
 
 
